cordova.define("com.instantencore.plugins.music.IeMusicPlayer.IeMusicPlayer", function(require, exports, module) { var IeMusicPlayer = function () {};
		
var eventIdTrackEndedUpdate = 'trackEnded-update';

/**
 * initWithListeners
 * Must be called before IeMusicPlayer can be used. This will start the service used
 * for music playback.
 * 
 * @param {Object} scope The scope to be used when callbacks are called.
 * @param {Function} fnTrackEndedListener Called when IeMusicPlayer fires a "TrackEnded" event. 
 */
IeMusicPlayer.prototype.initWithListeners = function(scope, fnTrackEndedListener) {
	
	//track ended listener
    document.addEventListener(
    		eventIdTrackEndedUpdate,
            function(event) {
    			fnTrackEndedListener.call(scope, event.eventDataPkg);
            });
	
    cordova.exec(null, null, "IeMusicPlayer", "initWithListeners", 
    		["window.plugins.iemusicplayer.trackEndedUpdate"]);
};

/**
 * Private helper function called by the native code to alert when track has ended.
 * This will trigger the function fnTrackEndedListener provided in "initWithListeners"
 */
IeMusicPlayer.prototype.trackEndedUpdate = function(eventDataPkg) {
 
        var ev = document.createEvent('HTMLEvents');
        ev.eventDataPkg = eventDataPkg;
        ev.initEvent(eventIdTrackEndedUpdate, true, true, arguments);
        document.dispatchEvent(ev);
 
};


/**
 * Determine if music is playing
 * 
 * @param {Function} callback Called when IeMusicPlayer returns a result. (returns bool true or false)	
 */
IeMusicPlayer.prototype.isPlaying = function(callback) {

    var cbSuccess = function(messageInt){ callback(messageInt === 1); };
    var cbFail = function(messageInt){ callback(false); };
    
    cordova.exec(cbSuccess, cbFail, "IeMusicPlayer", "isPlaying", []);
    
};

/**
 * Play a new url
 *
 * @param {String} url The url to play
 * @param {String} title The text that will go as "title" of Android Notification
 * @param {String} text The text that will go as "text" of Android Notification
 * @param {Integer} albumId The albumId for storing in service for later retrieval
 * @param {Integer} workId The workId for storing in service for later retrieval
 * @param {Integer} trackId The trackId for storing in service for later retrieval
 */
IeMusicPlayer.prototype.playUrl = function(url, title, text, albumId, workId, trackId) {
	cordova.exec(null, null, "IeMusicPlayer", "playUrl", [url, title, text, albumId, workId, trackId]);
};

/**
 * Resume playing.
 */
IeMusicPlayer.prototype.play = function() {
	cordova.exec(null, null, "IeMusicPlayer", "play", []);
};

/**
 * Pause music.
 * Also will remove the ongoing notification. 
 */
IeMusicPlayer.prototype.pause = function() {
	cordova.exec(null, null, "IeMusicPlayer", "pause", []);
};


IeMusicPlayer.prototype.seekToTime = function(sec) {
	cordova.exec(null, null, "IeMusicPlayer", "seekToTime", [sec]);
};

/**
 * Get the duration of the current audio
 * 
 * @param {Function} callback Called when IeMusicPlayer returns a result. (returns double for seconds or -1 if failed)	
 */
IeMusicPlayer.prototype.getDuration = function(callback) {
    
    var cbSuccess = function(messageDouble){ callback(messageDouble); };
    var cbFail = function(messageDouble){ callback(-1); };
    
    cordova.exec(cbSuccess, cbFail, "IeMusicPlayer", "getDuration", []);
    
};

/**
 * Get the position of the current audio
 * 
 * @param {Function} callback Called when IeMusicPlayer returns a result. (returns double for seconds or -1 if failed)	
 */
IeMusicPlayer.prototype.getCurrentPosition = function(callback) {
    
    var cbSuccess = function(messageDouble){ callback(messageDouble); };
    var cbFail = function(messageDouble){ callback(-1); };
    
    cordova.exec(cbSuccess, cbFail, "IeMusicPlayer", "getCurrentPosition", []);
    
};

/**
 * Get the details of the current audio track
 * 
 * @param {Function} callback Called when IeMusicPlayer returns a result. 
 * callback (returns JSON object with { albumId: 0, workId: 0, trackId: 0 } )
 */
IeMusicPlayer.prototype.getCurrentTrack = function(callback) {
    
    var cbSuccess = function(messageJsonObj){ callback(messageJsonObj); };
    var cbFail = function(messageJsonObj){ callback(null); };
    
    cordova.exec(cbSuccess, cbFail, "IeMusicPlayer", "getCurrentTrack", []);
    
};

/**
 * Stop will shutdown the media playback. Stopping playback and buffering. 
 */
IeMusicPlayer.prototype.stop = function() {
	cordova.exec(null, null, "IeMusicPlayer", "stop", []);
};

var iemusicplayer = new IeMusicPlayer();
module.exports = iemusicplayer;
});
