//Namespace work
var SwitchCaseGroup = window.SwitchCaseGroup || {};
SwitchCaseGroup.helpers = SwitchCaseGroup.helpers || {};

SwitchCaseGroup.helpers.Facebook = {

	LOGIN_STATUS_CONNECTED : 'connected',
	LOGIN_STATUS_NOT_AUTHORIZED : 'not_authorized',

	facebookAppId : null,

	permissions : {
		scope : ''
	},

	init : function(appId, perms) {

		try {

			var thisClass = SwitchCaseGroup.helpers.Facebook;

			thisClass.facebookAppId = appId;

			if (perms) {
				thisClass.permissions.scope = perms;
			}

			if ((typeof cordova == 'object') || (typeof Cordova == 'object')) {
                
                //Nothing to do for native at this point

			} else {
                
                if(facebookConnectPlugin){
                    facebookConnectPlugin.browserInit(thisClass.facebookAppId);
                }

			}

		} catch (e) {
			// FUTURE: do something about errors
		}

	},

	login : function(callback) {

		var thisClass = SwitchCaseGroup.helpers.Facebook;
        
        if(facebookConnectPlugin){
            
            facebookConnectPlugin.login(thisClass.permissions.scope, function(response) {

                thisClass.handleStatusResponse(response, callback);

            });
            
        }

	},

	logout : function(callback) {

		var thisClass = SwitchCaseGroup.helpers.Facebook;

        if(facebookConnectPlugin){
            
            facebookConnectPlugin.logout(function(response) {
                                        
                thisClass.handleStatusResponse(response, callback);
                                        
            });
            
        }
        
	},

	getLoginStatus : function(callback) {

		var thisClass = SwitchCaseGroup.helpers.Facebook;

        if(facebookConnectPlugin){
        	
        	facebookConnectPlugin.getLoginStatus(function(response) {

    			thisClass.handleStatusResponse(response, callback);

    		});
        	
        }

	},

	// Checks user is logged in otherwise prompts login then excutes provided function.
	// If login cancelled or fails execFn is never excuted
	// param execFn: is the function to be called
	// param execArgs: is an array of the parameters which are passed to that function.
	loginSafeExecution : function(execFn, execArgs) {

		var thisClass = SwitchCaseGroup.helpers.Facebook;

		var loginStatusCallback = function(status) {

			if (status == thisClass.LOGIN_STATUS_CONNECTED) {
				// LoginStatus check verified that user is connected
				// Therefore execute function (ie: post to wall)
				execFn.apply(this, execArgs);

			} else {
				// LoginStatus did NOT verify user is connected
				// Therefore try to login
				thisClass.login(function(status) {

					if (status == thisClass.LOGIN_STATUS_CONNECTED) {
						// Login was successful
						// Therefore execute function (ie: post to wall)
						execFn.apply(this, execArgs);

					}

				});

			}

		};

		thisClass.getLoginStatus(loginStatusCallback);

	},

	alertLoginStatus : function() {

		var thisClass = SwitchCaseGroup.helpers.Facebook;

		thisClass.getLoginStatus(function(status) {

			if (status === thisClass.LOGIN_STATUS_CONNECTED) {
				alert('connected');

			} else if (status === thisClass.LOGIN_STATUS_NOT_AUTHORIZED) {
				// the user is logged in to Facebook,
				// but has not authenticated your app
				alert('not_authorized');

			} else {
				alert('not logged in to Facebook');

			}

		});

	},

	alertLoggedInUser : function() {

		var thisClass = SwitchCaseGroup.helpers.Facebook;

		thisClass.getLoggedInUserBasicInfo(function(response) {
			alert('Your name is ' + response.name);
		});

	},

	getLoggedInUserBasicInfo : function(callback) {

		if(facebookConnectPlugin){
		        	
			facebookConnectPlugin.api('/me', thisClass.permissions.scope, callback);
		
		}

	},

	uiFacebookWallPost : function(fbWallPostParams) {

		// WARNING: funny things happen if this is called and user is not logged in.
		// example is that on native android this will use web login prompt (which is separate from native, wierd things can happen)
		// hint: leverage "loginSafeExecution" function in this class

		fbWallPostParams = fbWallPostParams || {};

		fbWallPostParams.method = 'feed';
		// fbWallPostParams.show_error = true;
		// fbWallPostParams.display = 'popup';
		fbWallPostParams.name = fbWallPostParams.name;// || 'Facebook Dialogs';
		fbWallPostParams.link = fbWallPostParams.link;// || 'https://developers.facebook.com/docs/reference/dialogs/';
		fbWallPostParams.picture = fbWallPostParams.picture;// || 'http://fbrell.com/f8.jpg';
		fbWallPostParams.caption = fbWallPostParams.caption;// || 'Reference Documentation';
		fbWallPostParams.description = fbWallPostParams.description;// || 'Dialogs provide a simple, consistent interface for applications to interface with users.';
		// pre-fill of message was deprecated in July 2011 breaking changes

		if(facebookConnectPlugin){
        	
			facebookConnectPlugin.showDialog(fbWallPostParams, function(obj) {
			});
			
		}

	},

	handleStatusResponse : function(response, callback) {

		var thisClass = SwitchCaseGroup.helpers.Facebook;

		var callbackIsFunction = typeof callback === 'function';

		var result = null;

		if (response.status === 'connected') {
			// the user is logged in and has authenticated your
			// app, and response.authResponse supplies
			// the user's ID, a valid access token, a signed
			// request, and the time the access token
			// and signed request each expire
			// alert('connected');
			result = thisClass.LOGIN_STATUS_CONNECTED;

		} else if (response.status === 'not_authorized') {
			// the user is logged in to Facebook,
			// but has not authenticated your app
			// alert('not_authorized');
			result = thisClass.LOGIN_STATUS_NOT_AUTHORIZED;

		} else {
			// the user isn't logged in to Facebook.
			// alert('not logged in to Facebook');
			result = null;

		}

		if (callbackIsFunction) {
			callback(result);
		}

	}

};
