//Namespace work
var SwitchCaseGroup = window.SwitchCaseGroup || {};
SwitchCaseGroup.helpers = SwitchCaseGroup.helpers || {};

SwitchCaseGroup.helpers.PushNotification = {
    
    c2dmSenderEmail: null,
    registeredCallback: null,
    
    /**
     * Will execute steps for platform appropriate push notification registration.
     * When a registrationToken is recieved the registeredCallback will be called, passing the token as the only parameter.
     * No other direct calls to this class are usually required.
     * Required to be called before this class is used.
     *
     * @param {Function} registeredCallback The function to be called when registered event occurs.
     * @param {String} c2dmSenderEmail The email address used with Android C2dm for registration and sending authentication.
     * @method
     */
    register: function (registeredCallback, c2dmSenderEmail) {

		try {
            
            var thisClass = SwitchCaseGroup.helpers.PushNotification;
            
            thisClass.registeredCallback = registeredCallback;
            
            if ( typeof window.plugins == 'object' ){
                
                var pushNotificationPlugin = window.plugins.pushNotification;
                
                if( typeof pushNotificationPlugin == 'object' ) {
                
                    //Android push notifications case (aka C2DM)
                    if (device.platform == 'android' || device.platform == 'Android') {
                        
                        thisClass.c2dmSenderEmail = c2dmSenderEmail;
                        
                        pushNotificationPlugin.register(
                                                  thisClass.successHandler,
                                                  thisClass.errorHandler,
                                                  {
                                                    "senderID":c2dmSenderEmail,
                                                    "ecb":"SwitchCaseGroup.helpers.PushNotification.onNotificationC2DM"
                                                  });
                        
                    } else {
        
                        pushNotificationPlugin.register(
                                                        thisClass.tokenHandlerIos,
                                                        thisClass.errorHandler,
                                                        {
                                                            "alert": "true",
                                                            "badge": "true",
                                                            "sound": "true",
                                                            "ecb":"SwitchCaseGroup.helpers.PushNotification.onNotificationAPN"
                                                        }
                                                        );
                
                    }
                    
                }
                
            }


		} catch (e) {
			//We just do not want this to break things.
		}

	},
    
    successHandler: function (result){
        //nothing
    },

    // result contains any error description text returned from the plugin call
    errorHandler: function (error){
        //alert('error = ' + error);
    },

    tokenHandlerIos: function (result) {
        // Your iOS push server needs to know the token before it can push to this device
        // here is where you might want to send it the token for later use.
        //alert('device token = ' + result);
        
        var thisClass = SwitchCaseGroup.helpers.PushNotification;
        
        if( typeof thisClass.registeredCallback === 'function' ){
        
            // if successful result is an object that looks like this:
            // {"type":"7","pushBadge":"1","pushSound":"1","enabled":"1","deviceToken":"blablahblah","pushAlert":"1"}
            if (result && result.deviceToken) {
                
                //console.log(JSON.strigify(result));
                
                thisClass.registeredCallback.call(this, result.deviceToken, result.pushAlert, result.pushBadge, result.pushSound );
                
            }
        
        }
        
    },

    // iOS
    onNotificationAPN: function (event) {
        /*//We do nothing here
        if ( event.alert )
        {
            navigator.notification.alert(event.alert);
        }
        
        if ( event.sound )
        {
            var snd = new Media(event.sound);
            snd.play();
        }
        
        if ( event.badge )
        {
            pushNotification.setApplicationIconBadgeNumber(successHandler, errorHandler, event.badge);
        }
        */
    },


    // Android
    onNotificationC2DM: function (e) {
        
        var thisClass = SwitchCaseGroup.helpers.PushNotification;
        
        switch( e.event )
        {
            case 'registered':
                
				// the definition of the e variable is json return defined in C2DMReceiver.java
                
				if (e.regid.length > 0 && (typeof thisClass.registeredCallback) === 'function' ) {
                    
					//alert('REGISTERED -> REGID:' + e.regid);
                    
                    thisClass.registeredCallback.call(this, e.regid);
					
				}
                break;
                
            case 'message':
                /*
                // if this flag is set, this notification happened while we were in the foreground.
                // you might want to play a sound to get the user's attention, throw up a dialog, etc.
                if ( e.foreground )
                {
                    //We are doing nothing here for now
                }
                else
                {  // otherwise we were launched because the user touched a notification in the notification tray.
                    if ( e.coldstart )
                    {
                        //We are doing nothing here for now
                    }
                    else
                    {
                        //We are doing nothing here for now
                    }
                }
                
                //console.log('MSG: ' + e.payload.message);
                //console.log('MSGCNT: ' + e.payload.msgcnt);
                */
                break;
                
            case 'error':
                //console.log('ERROR -> MSG:' + e.msg);
                break;
                
            default:
                //console.log('EVENT -> Unknown, an event was received and we do not know what it is');
                break;
                
        }
        
    }

};